@@ -194,8 +194,8 @@ class WordForm(models.Model):
             nd,fwnd = t.get_neigh_densities()
             nd_sum += nd
             fwnd_sum += fwnd
-        nd = float(nd_sum)/float(len(self.transcriptions.all())
-        fwnd = float(fwnd_sum)/float(len(self.transcriptions.all())
+        nd = float(nd_sum)/float(len(self.transcriptions.all()))
+        fwnd = float(fwnd_sum)/float(len(self.transcriptions.all()))
         return nd,fwnd
 
     def get_phono_prob(self):
